==> apache-cxf-3.4.5-src.tar.gz: apache-cxf-3.4.5-src/systests/microprofile/client/nocdi/src/test/java/org/apache/cxf/systest/microprofile/rest/client/mock/AsyncClientWithCompletionStage.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.microprofile.rest.client.mock;

import java.util.Collection;
import java.util.concurrent.CompletionStage;

import javax.json.JsonObject;
import javax.json.JsonStructure;
import javax.ws.rs.GET;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.core.Response;

public interface AsyncClientWithCompletionStage {

    @PUT
    @Path("/test")
    CompletionStage<Response> put(String text);
    
    @GET
    @Path("/test2")
    @Produces("application/json")
    CompletionStage<JsonStructure> get();
    
    @GET
    @Path("/test3")
    @Produces("application/json")
    CompletionStage<Collection<JsonObject>> getAll();
}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/systests/microprofile/client/nocdi/src/test/java/org/apache/cxf/systest/microprofile/rest/client/mock/AsyncClientWithCompletionStage.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.systest.microprofile.rest.client.mock;

import java.util.Collection;
import java.util.concurrent.CompletionStage;

import jakarta.json.JsonObject;
import jakarta.json.JsonStructure;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.PUT;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.Response;

public interface AsyncClientWithCompletionStage {

    @PUT
    @Path("/test")
    CompletionStage<Response> put(String text);
    
    @GET
    @Path("/test2")
    @Produces("application/json")
    CompletionStage<JsonStructure> get();
    
    @GET
    @Path("/test3")
    @Produces("application/json")
    CompletionStage<Collection<JsonObject>> getAll();
}
